@@ -1,8 +1,9 @@
 from .extract import Bodyline, Footnote
 from .fetch import (
+    get_img_from_page,
     get_page_and_img,
+    get_pages_and_imgs,
     get_reverse_pages_and_imgs,
-    get_terminal_page_pos,
 )
 from .slice import (
     PageCut,
